* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance)
  * Obsolescence Risk Management Capabilities
